@@ -15,9 +15,15 @@ representations to libgps structures.
 #include <stdlib.h>
 #include <stddef.h>
 
-#include "gpsd.h"
+#include "gpsd_config.h"
+#include "gps.h"
+#include "json.h"
 #ifdef SOCKET_EXPORT_ENABLE
-#include "gps_json.h"
+
+/* FIXME: kluges because we don't want to include gpsd.h here */
+extern int gpsd_hexpack(/*@in@*/const char *, /*@out@*/char *, size_t);
+int json_ais_read(const char *, char *, size_t, struct ais_t *, 
+		  /*@null@*/const char **);
 
 /*@ -mustdefine @*/
 static void lenhex_unpack(const char *from,
