@@ -35,10 +35,10 @@
 /* This is how many display fields are output in the 'datawin' window
    when in GPS mode.  Change this value if you add or remove fields
    from the 'datawin' window for the GPS mode. */
-#define DATAWIN_GPS_FIELDS 9
+#define DATAWIN_GPS_FIELDS 8
 
 /* Count of optional fields that we'll display if we have the room. */
-#define DATAWIN_OPTIONAL_FIELDS 6
+#define DATAWIN_OPTIONAL_FIELDS 7
 
 /* This is how many display fields are output in the 'datawin' window
    when in COMPASS mode.  Change this value if you add or remove fields
@@ -131,74 +131,6 @@ static bool compass_flag = false;
 #define GPS_ERROR	-2	/* low-level failure in GPS read */
 #define GPS_TIMEOUT	-3	/* low-level failure in GPS waiting */
 
-/* Convert true heading to magnetic.  Taken from the Aviation
-   Formulary v1.43.  Valid to within two degrees within the
-   continiental USA except for the following airports: MO49 MO86 MO50
-   3K6 02K and KOOA.  AK correct to better than one degree.  Western
-   Europe correct to within 0.2 deg.
-
-   If you're not in one of these areas, I apologize, I don't have the
-   math to compute your varation.  This is obviously extremely
-   floating-point heavy, so embedded people, beware of using.
-
-   Note that there are issues with using magnetic heading.  This code
-   does not account for the possibility of travelling into or out of
-   an area of valid calculation beyond forcing the magnetic conversion
-   off.  A better way to communicate this to the user is probably
-   desirable (in case the don't notice the subtle change from "(mag)"
-   to "(true)" on their display).
- */
-static float true2magnetic(double lat, double lon, double heading)
-{
-    /* Western Europe */
-    /*@ -evalorder +relaxtypes @*/
-    if ((lat > 36.0) && (lat < 68.0) && (lon > -10.0) && (lon < 28.0)) {
-	heading =
-	    (10.4768771667158 - (0.507385322418858 * lon) +
-	     (0.00753170031703826 * pow(lon, 2))
-	     - (1.40596203924748e-05 * pow(lon, 3)) -
-	     (0.535560699962353 * lat)
-	     + (0.0154348808069955 * lat * lon) -
-	     (8.07756425110592e-05 * lat * pow(lon, 2))
-	     + (0.00976887198864442 * pow(lat, 2)) -
-	     (0.000259163929798334 * lon * pow(lat, 2))
-	     - (3.69056939266123e-05 * pow(lat, 3)) + heading);
-    }
-    /* USA */
-    else if ((lat > 24.0) && (lat < 50.0) && (lon > 66.0) && (lon < 125.0)) {
-	lon = 0.0 - lon;
-	heading =
-	    ((-65.6811) + (0.99 * lat) + (0.0128899 * pow(lat, 2)) -
-	     (0.0000905928 * pow(lat, 3)) + (2.87622 * lon)
-	     - (0.0116268 * lat * lon) - (0.00000603925 * lon * pow(lat, 2)) -
-	     (0.0389806 * pow(lon, 2))
-	     - (0.0000403488 * lat * pow(lon, 2)) +
-	     (0.000168556 * pow(lon, 3)) + heading);
-    }
-    /* AK */
-    else if ((lat > 54.0) && (lon > 130.0) && (lon < 172.0)) {
-	lon = 0.0 - lon;
-	heading =
-	    (618.854 + (2.76049 * lat) - (0.556206 * pow(lat, 2)) +
-	     (0.00251582 * pow(lat, 3)) - (12.7974 * lon)
-	     + (0.408161 * lat * lon) + (0.000434097 * lon * pow(lat, 2)) -
-	     (0.00602173 * pow(lon, 2))
-	     - (0.00144712 * lat * pow(lon, 2)) +
-	     (0.000222521 * pow(lon, 3)) + heading);
-    } else {
-	/* We don't know how to compute magnetic heading for this
-	 * location. */
-	magnetic_flag = false;
-    }
-
-    /* No negative headings. */
-    if (heading < 0.0)
-	heading += 360.0;
-
-    return (heading);
-    /*@ +evalorder -relaxtypes @*/
-}
-
 /* Function to call when we're all done.  Does a bit of clean-up. */
 static void die(int sig)
 {
@@ -378,7 +310,6 @@ static void windowsetup(void)
 	(void)mvwprintw(datawin, 6, DATAWIN_DESC_OFFSET, "Heading:");
 	(void)mvwprintw(datawin, 7, DATAWIN_DESC_OFFSET, "Climb:");
 	(void)mvwprintw(datawin, 8, DATAWIN_DESC_OFFSET, "Status:");
-	(void)mvwprintw(datawin, 9, DATAWIN_DESC_OFFSET, "GPS Type:");
 
 	/* Note that the following fields are exceptions to the
 	 * sizing rule.  The minimum window size does not include these
@@ -389,15 +320,16 @@ static void windowsetup(void)
 	 * sounded interesting. ;^) */
 
 	if (window_length == MAX_GPS_DATAWIN_SIZE) {
-	    (void)mvwprintw(datawin, 10, DATAWIN_DESC_OFFSET,
+	    (void)mvwprintw(datawin, 9, DATAWIN_DESC_OFFSET,
 			    "Longitude Err:");
-	    (void)mvwprintw(datawin, 11, DATAWIN_DESC_OFFSET,
+	    (void)mvwprintw(datawin, 10, DATAWIN_DESC_OFFSET,
 			    "Latitude Err:");
-	    (void)mvwprintw(datawin, 12, DATAWIN_DESC_OFFSET,
+	    (void)mvwprintw(datawin, 11, DATAWIN_DESC_OFFSET,
 			    "Altitude Err:");
-	    (void)mvwprintw(datawin, 13, DATAWIN_DESC_OFFSET, "Course Err:");
-	    (void)mvwprintw(datawin, 14, DATAWIN_DESC_OFFSET, "Speed Err:");
-	    /* it's actually esr that thought *this* one was interesting */
+	    (void)mvwprintw(datawin, 12, DATAWIN_DESC_OFFSET, "Course Err:");
+	    (void)mvwprintw(datawin, 13, DATAWIN_DESC_OFFSET, "Speed Err:");
+	    /* it's actually esr that thought *these* were interesting */
+	    (void)mvwprintw(datawin, 14, DATAWIN_DESC_OFFSET, "Time offset:");
 	    (void)mvwprintw(datawin, 15, DATAWIN_DESC_OFFSET, "Grid Square:");
 	}
 
@@ -474,8 +406,9 @@ static void update_compass_panel(struct gps_data_t *gpsdata)
 }
 #endif /* TRUENORTH */
 
-/* This gets called once for each new GPS sentence. */
+/*@-mustfreefresh@*/
 static void update_gps_panel(struct gps_data_t *gpsdata)
+/* This gets called once for each new GPS sentence. */
 {
     int i, j, n;
     int newstate;
@@ -567,7 +500,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
     (void)mvwprintw(datawin, 3, DATAWIN_VALUE_OFFSET, "%-*s", 27, scr);
 
     /* Fill in the altitude. */
-    if (gpsdata->fix.mode == MODE_3D && isnan(gpsdata->fix.altitude) == 0)
+    if (gpsdata->fix.mode >= MODE_3D && isnan(gpsdata->fix.altitude) == 0)
 	(void)snprintf(scr, sizeof(scr), "%.1f %s",
 		       gpsdata->fix.altitude * altfactor, altunits);
     else
@@ -583,21 +516,23 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
     (void)mvwprintw(datawin, 5, DATAWIN_VALUE_OFFSET, "%-*s", 27, scr);
 
     /* Fill in the heading. */
-    if (gpsdata->fix.mode >= MODE_2D && isnan(gpsdata->fix.track) == 0)
-	if (!magnetic_flag) {
+    if (gpsdata->fix.mode >= MODE_2D && isnan(gpsdata->fix.track) == 0) {
+	double magheading = true2magnetic(gpsdata->fix.latitude,
+					 gpsdata->fix.longitude,
+					  gpsdata->fix.track);
+	if (!magnetic_flag || isnan(magheading) != 0) {
 	    (void)snprintf(scr, sizeof(scr), "%.1f deg (true)",
 			   gpsdata->fix.track);
 	} else {
 	    (void)snprintf(scr, sizeof(scr), "%.1f deg (mag) ",
-			   true2magnetic(gpsdata->fix.latitude,
-					 gpsdata->fix.longitude,
-					 gpsdata->fix.track));
+		magheading);
+	}
     } else
 	(void)snprintf(scr, sizeof(scr), "n/a");
     (void)mvwprintw(datawin, 6, DATAWIN_VALUE_OFFSET, "%-*s", 27, scr);
 
     /* Fill in the rate of climb. */
-    if (gpsdata->fix.mode == MODE_3D && isnan(gpsdata->fix.climb) == 0)
+    if (gpsdata->fix.mode >= MODE_3D && isnan(gpsdata->fix.climb) == 0)
 	(void)snprintf(scr, sizeof(scr), "%.1f %s/min",
 		       gpsdata->fix.climb * altfactor * 60, altunits);
     else
@@ -632,17 +567,11 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
     }
     (void)mvwprintw(datawin, 8, DATAWIN_VALUE_OFFSET, "%-*s", 27, scr);
 
-    /* Fill in receiver type. */
-    for (i = 0; i < gpsdata->devices.ndevices; i++)
-	if (strcmp(gpsdata->devices.list[i].path, gpsdata->dev.path) == 0)
-	   break;
-    (void)snprintf(scr, sizeof(scr), "%s", gpsdata->devices.list[i].driver);
-    (void)mvwprintw(datawin, 9, DATAWIN_VALUE_OFFSET, "%-*s", 27, scr);
     /* Note that the following fields are exceptions to the
      * sizing rule.  The minimum window size does not include these
      * fields, if the window is too small, they get excluded.  This
      * may or may not change if/when the output for these fields is
-     * fixed and/or people request their permanance.  They're only
+     * fixed and/or people request their permanence.  They're only
      * there in the first place because I arbitrarily thought they
      * sounded interesting. ;^) */
 
@@ -654,7 +583,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
 			   (int)(gpsdata->fix.epx * altfactor), altunits);
 	else
 	    (void)snprintf(scr, sizeof(scr), "n/a");
-	(void)mvwprintw(datawin, 10, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
+	(void)mvwprintw(datawin, 9, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
 			scr);
 
 	if (isnan(gpsdata->fix.epy) == 0)
@@ -662,7 +591,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
 			   (int)(gpsdata->fix.epy * altfactor), altunits);
 	else
 	    (void)snprintf(scr, sizeof(scr), "n/a");
-	(void)mvwprintw(datawin, 11, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
+	(void)mvwprintw(datawin, 10, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
 			scr);
 
 	/* Fill in the estimated vertical position error. */
@@ -671,7 +600,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
 			   (int)(gpsdata->fix.epv * altfactor), altunits);
 	else
 	    (void)snprintf(scr, sizeof(scr), "n/a");
-	(void)mvwprintw(datawin, 12, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
+	(void)mvwprintw(datawin, 11, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
 			scr);
 
 	/* Fill in the estimated track error. */
@@ -680,7 +609,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
 			   (int)(gpsdata->fix.epd));
 	else
 	    (void)snprintf(scr, sizeof(scr), "n/a");
-	(void)mvwprintw(datawin, 13, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
+	(void)mvwprintw(datawin, 12, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
 			scr);
 
 	/* Fill in the estimated speed error. */
@@ -689,7 +618,15 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
 			   (int)(gpsdata->fix.eps * speedfactor), speedunits);
 	else
 	    (void)snprintf(scr, sizeof(scr), "n/a");
-	(void)mvwprintw(datawin, 14, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
+	(void)mvwprintw(datawin, 13, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22,
+			scr);
+	/* Fill in the time offset. */
+	if (isnan(gpsdata->fix.time) == 0)
+	    (void)snprintf(scr, sizeof(scr), "%.3f",
+			   (double)(timestamp()-gpsdata->fix.time));
+	else
+	    (void)snprintf(scr, sizeof(scr), "n/a");
+	(void)mvwprintw(datawin, 14, DATAWIN_VALUE_OFFSET + 5, "%-*s", 22, 
 			scr);
 	/* Fill in the grid square (esr thought *this* one was interesting). */
 	/*@-branchstate@*/
@@ -702,8 +639,8 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
     }
 
     /* Be quiet if the user requests silence. */
-    if (!silent_flag && raw_flag) {
-	(void)waddstr(messages, gps_data(gpsdata));
+    if (!silent_flag && raw_flag && (s = (char *)gps_data(gpsdata)) != NULL) {
+	(void)waddstr(messages, s);
     }
 
     /* Reset the status_timer if the state has changed. */
@@ -718,6 +655,7 @@ static void update_gps_panel(struct gps_data_t *gpsdata)
 	(void)wrefresh(messages);
     }
 }
+/*@+mustfreefresh@*/
 
 static void usage(char *prog)
 {
