@@ -7,6 +7,7 @@
 #endif /* S_SPLINT_S */
 
 #include "gpsd_config.h"
+#ifndef HAVE_DAEMON
 #if defined (HAVE_PATH_H)
 #include <paths.h>
 #else
@@ -19,10 +20,9 @@ int daemon(int nochdir, int noclose)
 /* compatible with the daemon(3) found on Linuxes and BSDs */
 {
     int fd;
-    pid_t pid;
 
     /*@ -type @*//* weirdly, splint 3.1.2 is confused by fork() */
-    switch (pid = fork()) {
+    switch (fork()) {
     case -1:
 	return -1;
     case 0:			/* child side */
@@ -47,3 +47,7 @@ int daemon(int nochdir, int noclose)
     /*@ +nullpass @*/
     return 0;
 }
+
+#endif /* HAVE_DAEMON */
+
+// end
