@@ -201,15 +201,15 @@ static gps_mask_t handle1000(struct gps_device_t *session)
     /* clock_drift_sd              = (int)getzlong(53) * 1e-2; */
 
     mask =
-	TIME_IS | LATLON_IS | ALTITUDE_IS | CLIMB_IS | SPEED_IS | TRACK_IS |
-	STATUS_IS | MODE_IS;
+	TIME_SET | PPSTIME_IS | LATLON_SET | ALTITUDE_SET | CLIMB_SET | SPEED_SET |
+	TRACK_SET | STATUS_SET | MODE_SET;
     gpsd_report(LOG_DATA,
-		"1000: time=%.2f lat=%.2f lon=%.2f alt=%.2f track=%.2f speed=%.2f climb=%.2f mode=%d status=%d mask=%s\n",
+		"1000: time=%.2f lat=%.2f lon=%.2f alt=%.2f track=%.2f speed=%.2f climb=%.2f mode=%d status=%d\n",
 		session->newdata.time, session->newdata.latitude,
 		session->newdata.longitude, session->newdata.altitude,
 		session->newdata.track, session->newdata.speed,
 		session->newdata.climb, session->newdata.mode,
-		session->gpsdata.status, gpsd_maskdump(mask));
+		session->gpsdata.status);
     return mask;
 }
 
@@ -251,7 +251,7 @@ static gps_mask_t handle1002(struct gps_device_t *session)
     gpsd_report(LOG_DATA, "1002: visible=%d used=%d mask={SATELLITE|USED}\n",
 		session->gpsdata.satellites_visible,
 		session->gpsdata.satellites_used);
-    return SATELLITE_IS | USED_IS;
+    return SATELLITE_SET | USED_IS;
 }
 
 static gps_mask_t handle1003(struct gps_device_t *session)
@@ -300,7 +300,7 @@ static gps_mask_t handle1003(struct gps_device_t *session)
 		session->gpsdata.dop.hdop,
 		session->gpsdata.dop.vdop,
 		session->gpsdata.dop.pdop, session->gpsdata.dop.tdop);
-    return SATELLITE_IS | DOP_IS;
+    return SATELLITE_SET | DOP_SET;
 }
 
 static void handle1005(struct gps_device_t *session UNUSED)
@@ -329,7 +329,7 @@ static gps_mask_t handle1011(struct gps_device_t *session)
     getstringz(session->subtype, session->packet.outbuffer, 19, 28);	/* software version field */
     gpsd_report(LOG_DATA, "1011: subtype=%s mask={DEVICEID}\n",
 		session->subtype);
-    return DEVICEID_IS;
+    return DEVICEID_SET;
 }
 
 
@@ -419,7 +419,7 @@ static gps_mask_t zodiac_analyze(struct gps_device_t *session)
     }
 }
 
-#ifdef ALLOW_CONTROLSEND
+#ifdef CONTROLSEND_ENABLE
 static ssize_t zodiac_control_send(struct gps_device_t *session,
 				   char *msg, size_t len)
 {
@@ -429,9 +429,9 @@ static ssize_t zodiac_control_send(struct gps_device_t *session,
     return zodiac_spew(session, shortwords[0], shortwords + 1,
 		       (int)(len / 2 - 1));
 }
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
 static bool zodiac_speed_switch(struct gps_device_t *session,
 				speed_t speed, char parity, int stopbits)
 {
@@ -469,7 +469,7 @@ static bool zodiac_speed_switch(struct gps_device_t *session,
     (void)zodiac_spew(session, 1330, data, 15);
     return true;		/* it would be nice to error-check this */
 }
-#endif /* ALLOW_RECONFIGURE */
+#endif /* RECONFIGURE_ENABLE */
 
 #ifdef NTPSHM_ENABLE
 static double zodiac_ntp_offset(struct gps_device_t *session UNUSED)
@@ -496,15 +496,15 @@ const struct gps_type_t zodiac_binary =
     .parse_packet   = zodiac_analyze,	/* parse message packets */
     .rtcm_writer    = zodiac_send_rtcm,	/* send DGPS correction */
     .event_hook     = NULL,		/* no configuration */
-#ifdef ALLOW_RECONFIGURE
+#ifdef RECONFIGURE_ENABLE
     .speed_switcher = zodiac_speed_switch,/* we can change baud rate */
     .mode_switcher  = NULL,		/* no mode switcher */
     .rate_switcher  = NULL,		/* no sample-rate switcher */
     .min_cycle      = 1,		/* not relevant, no rate switch */
-#endif /* ALLOW_RECONFIGURE */
-#ifdef ALLOW_CONTROLSEND
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
     .control_send   = zodiac_control_send,	/* for gpsctl and friends */
-#endif /* ALLOW_CONTROLSEND */
+#endif /* CONTROLSEND_ENABLE */
 #ifdef NTPSHM_ENABLE
     .ntp_offset     = zodiac_ntp_offset,	/* compute NTO fudge factor */
 #endif /* NTPSHM_ENABLE */
