@@ -865,6 +865,75 @@ static const struct gps_type_t oceanServer = {
 /* *INDENT-ON* */
 #endif
 
+#ifdef FURY_ENABLE
+/**************************************************************************
+ *
+ * Jackson Labs Fury, a high-precision laboratory clock
+ *
+ * Will also support other Jackon Labs boards, including the Firefly.
+ *
+ * Note: you must either build with fixed_port_speed=115200 or tweak the 
+ * speed on the port to 115200 before running.  The device's default mode
+ * does not stream output, so our hunt loop will simply time out otherwise.
+ *
+ **************************************************************************/
+
+static bool fury_rate_switcher(struct gps_device_t *session, double rate)
+{
+    char buf[78];
+    double inverted;
+
+    /* rate is a frequency, but the command takes interval in # of sedconds */
+    if (rate == 0.0)
+	inverted = 0.0;
+    else
+	inverted = 1.0/rate;
+    if (inverted > 256)
+	return false;
+    (void)snprintf(buf, sizeof(buf), "GPS:GPGGA %d\r\n", (int)inverted);
+    (void)gpsd_write(session, buf, strlen(buf));
+    return true;
+}
+
+static void fury_event_hook(struct gps_device_t *session, event_t event)
+{
+    if (event == event_wakeup && gpsd_get_speed(&session->ttyset) == 115200)
+	(void)fury_rate_switcher(session, 1.0);
+    else if (event == event_deactivate)
+	(void)fury_rate_switcher(session, 0.0);
+}
+
+
+/* *INDENT-OFF* */
+static const struct gps_type_t fury = {
+    .type_name      = "Jackson Labs Fury", /* full name of type */
+    .packet_type    = NMEA_PACKET,	/* associated lexer packet type */
+    .flags	    = DRIVER_NOFLAGS,	/* no rollover or other flags */
+    .trigger	    = NULL,		/* detect their main sentence */
+    .channels       = 0,		/* not an actual GPS at all */
+    .probe_detect   = NULL,
+    .get_packet     = generic_get,	/* how to get a packet */
+    .parse_packet   = generic_parse_input,	/* how to interpret a packet */
+    .rtcm_writer    = NULL,		/* Don't send */
+    .event_hook     = fury_event_hook,
+#ifdef RECONFIGURE_ENABLE
+    .speed_switcher = NULL,		/* no speed switcher */
+    .mode_switcher  = NULL,		/* no mode switcher */
+    .rate_switcher  = fury_rate_switcher,
+    .min_cycle      = 1,		/* has rate switch */
+#endif /* RECONFIGURE_ENABLE */
+#ifdef CONTROLSEND_ENABLE
+    .control_send   = nmea_write,	/* how to send control strings */
+#endif /* CONTROLSEND_ENABLE */
+#ifdef NTPSHM_ENABLE
+    .ntp_offset     = NULL,
+#endif /* NTPSHM_ ENABLE */
+};
+/* *INDENT-ON* */
+
+#endif /* FURY_ENABLE */
+
+
 #ifdef RTCM104V2_ENABLE
 /**************************************************************************
  *
@@ -1227,7 +1296,7 @@ static gps_mask_t json_pass_packet(struct gps_device_t *session UNUSED)
     if (strstr((char *)session->packet.outbuffer, "VERSION") != NULL
 	|| strstr((char *)session->packet.outbuffer, "WATCH") != NULL
 	|| strstr((char *)session->packet.outbuffer, "DEVICES") != NULL) {
-	session->packet.outbuffer[session->packet.outbuflen] = '\0';	
+	session->packet.outbuffer[session->packet.outbuflen-1] = '\0';	
 	(void)strlcat((char *)session->packet.outbuffer, ",\"remote\":\"", 
 		      sizeof(session->packet.outbuffer));
 	(void)strlcat((char *)session->packet.outbuffer,
@@ -1312,6 +1381,9 @@ static const struct gps_type_t *gpsd_driver_array[] = {
 #ifdef TNT_ENABLE
     &trueNorth,
 #endif /* TNT_ENABLE */
+#ifdef FURY_ENABLE
+    &fury,
+#endif /* FURY_ENABLE */
 #ifdef AIVDM_ENABLE
     &aivdm,
 #endif /* AIVDM_ENABLE */
