@@ -33,7 +33,7 @@ extern "C" {
 /*
  * 4.1 - Base version for initial JSON protocol (Dec 2009, release 2.90)
  * 4.2 - AIS application IDs split into DAC and FID (July 2010, release 2.95)
- * 5.0 - MAXCHANNELS bumped from 20 to 32 for GLONASS (July 2010)
+ * 5.0 - MAXCHANNELS bumped from 20 to 32 for GLONASS (Mar 2011, release 2.96)
  *       gps_open() becomes reentrant, what gps_open_r() used to be. 
  *       gps_poll() removed in favor of gps_read().  The raw hook is gone.
  */
@@ -96,6 +96,17 @@ struct gps_fix_t {
     double epc;		/* Vertical speed uncertainty */
 };
 
+/*
+ * Satellite ID classes.
+ * U.S. GPS authorities reserve PRNs 1-64 for GPS satellites.
+ * GLONASS birds reuse GPS PRNs;  it is a GPSD convention to map them to 
+ * IDs 64 and above (some other programs push them to 33 and above).
+ * All SBAS/WAAS/EGNOS birds have PRNs above 100.
+ */
+#define GNSS_PRN(n)	(((n) >= 1) && ((n) <= 63))	/* GNSS satellite */
+#define GLONASS_PRN(n)	(((n) >= 64) && ((n) <= 96))	/* GLONASS satellite */
+#define DGPS_PRN(n)	((n) >= 100)
+
 /* 
  * The structure describing the pseudorange errors (GPGST)
  */
@@ -1646,6 +1657,7 @@ struct gps_data_t {
 #endif
     struct gps_fix_t	fix;	/* accumulated PVT data */
 
+    /* this should move to the per-driver structure */
     double separation;		/* Geoidal separation, MSL - WGS84 (Meters) */
 
     /* GPS status -- always valid */
@@ -1710,21 +1722,15 @@ extern int gps_read(/*@out@*/struct gps_data_t *);
 extern int gps_unpack(char *, struct gps_data_t *);
 extern bool gps_waiting(const struct gps_data_t *, int);
 extern int gps_stream(struct gps_data_t *, unsigned int, /*@null@*/void *);
-extern const char /*@observer@*/ *gps_data(const struct gps_data_t *);
+extern int gps_mainloop(struct gps_data_t *, int,
+			void (*)(struct gps_data_t *));
+extern const char /*@null observer@*/ *gps_data(const struct gps_data_t *);
 extern const char /*@observer@*/ *gps_errstr(const int);
 
-extern int gps_sock_open(/*@null@*/const char *, /*@null@*/const char *, 
-		      /*@out@*/struct gps_data_t *);
-extern int gps_sock_read(/*@out@*/struct gps_data_t *);
-extern int gps_sock_close(struct gps_data_t *);
-extern int gps_shm_open(/*@out@*/struct gps_data_t *);
-extern int gps_shm_read(struct gps_data_t *);
-extern void gps_shm_close(struct gps_data_t *);
+/* dependencies on struct gpsdata_t end hrere */
 
 extern void libgps_trace(int errlevel, const char *, ...);
 
-/* dependencies on struct gpsdata_t end hrere */
-
 extern void gps_clear_fix(/*@ out @*/struct gps_fix_t *);
 extern void gps_clear_dop( /*@out@*/ struct dop_t *);
 extern void gps_merge_fix(/*@ out @*/struct gps_fix_t *,
@@ -1733,6 +1739,7 @@ extern void gps_merge_fix(/*@ out @*/struct gps_fix_t *,
 extern void gps_enable_debug(int, FILE *);
 extern /*@observer@*/const char *gps_maskdump(gps_mask_t);
 
+extern double safe_atof(const char *);
 extern time_t mkgmtime(register struct tm *);
 extern timestamp_t timestamp(void);
 extern timestamp_t iso8601_to_unix(char *);
@@ -1773,12 +1780,14 @@ extern double wgs84_separation(double, double);
 #define NL_NOCONNECT	-6	/* can't connect to host/socket pair */
 #define SHM_NOSHARED	-7	/* shared-memory segment not available */
 #define SHM_NOATTACH	-8	/* shared-memory attach failed */
+#define DBUS_FAILURE	-9	/* DBUS initialization failure */
 
 #define DEFAULT_GPSD_PORT	"2947"	/* IANA assignment */
 #define DEFAULT_RTCM_PORT	"2101"	/* IANA assignment */
 
 /* special host values for non-socket exports */ 
 #define GPSD_SHARED_MEMORY	"shared memory"
+#define GPSD_DBUS_EXPORT	"DBUS export"
 
 /*
  * Platform-specific declarations
@@ -1800,5 +1809,5 @@ size_t strlcpy(/*@out@*/char *dst, /*@in@*/const char *src, size_t size);
 }  /* End of the 'extern "C"' block */
 #endif
 
-/* gps.h ends here */
 #endif /* _GPSD_GPS_H_ */
+/* gps.h ends here */
