@@ -56,7 +56,7 @@ class GPSDictionary(ConfigParser.RawConfigParser):
                     raise ConfigParser.Error("%s has invalid vendor" % section)
 
     def HTMLDump(self, ofp):
-        thead = """<table border='1' style='font-size:small;' bgcolor='#CCCCCC'>
+        thead = """<table border='1' style='font-size:small;background-color:#CCCCCC'>
 <caption>Listing %s devices from %s vendors</caption>
 <tr>
 <th>Name</th>
@@ -65,21 +65,25 @@ class GPSDictionary(ConfigParser.RawConfigParser):
 <th>Interface</th>
 <th>Tested with</th>
 <th>NMEA version</th>
-<th width='50%%'>Notes</th>
+<th style='width:50%%'>Notes</th>
 </tr>
 """
-        vhead = "<tr><td style='text-align:center;' colspan='7'><a href='%s'>%s</a></td></tr>\n"
+        vhead1 = "<tr><td style='text-align:center;' colspan='7'><a href='%s'>%s</a></td></tr>\n"
+        vhead2 = "<tr><td style='text-align:center;' colspan='7'><a href='%s'>%s</a><br><p>%s</p></td></tr>\n"
         hotpluggables = ("pl2303", "CP2101")
         ofp.write(thead % (len(self.devices), len(self.vendors)))
         for vendor in self.vendors:
-            ofp.write(vhead % (self.get(vendor, "vendor_site"), vendor))
+            if self.has_option(vendor, "notes"):
+                ofp.write(vhead2 % (self.get(vendor, "vendor_site"), vendor, self.get(vendor, "notes")))
+            else:
+                ofp.write(vhead1 % (self.get(vendor, "vendor_site"), vendor))
             relevant = []
             for dev in self.devices:
                 if self.get(dev, "vendor") == vendor:
                     relevant.append(dev)
             relevant.sort()
             for dev in relevant:
-                rowcolor = "#FFFFFF"
+                rowcolor = "white"
                 if self.get(dev, "packaging") == "OEM module":
                     rowcolor = "LimeGreen"
                 elif self.get(dev, "packaging") == "chipset":
@@ -89,12 +93,12 @@ class GPSDictionary(ConfigParser.RawConfigParser):
                 elif self.get(dev, "packaging") == "hansdfree":
                     rowcolor = "DarkCyan"
 
-                ofp.write("<tr bgcolor='%s'>\n" % rowcolor)
+                ofp.write("<tr style='background-color:%s'>\n" % rowcolor)
                 namefield = dev
                 if self.has_option(dev, "techdoc"):
                     namefield = "<a href='%s'>%s</a>" % (self.get(dev, "techdoc"), dev)
                 if self.has_option(dev, "discontinued"):
-                    namefield = namefield + "&nbsp;<img title='Device discontinued' src='discontinued.png'/>"
+                    namefield = namefield + "&nbsp;<img title='Device discontinued' src='discontinued.png' alt='Discontinued icon'>"
                 ofp.write("<td>%s</td>\n" % namefield)
                 ofp.write("<td>%s</td>\n" % self.get(dev, "packaging"))
                 engine = self.get(dev, "engine")
@@ -111,23 +115,23 @@ class GPSDictionary(ConfigParser.RawConfigParser):
                 if self.has_option(dev, "tested"):
                     tested = self.get(dev, "tested")
                     if tested == "regression":
-                        testfield += "<img title='Have regression test' src='regression.png'>"
+                        testfield += "<img title='Have regression test' src='regression.png' alt='Regression-test icon'>"
                     else:
                         testfield += tested
                 if self.has_option(dev, "noconfigure"):
-                    testfield += "<img title='Requires -b option' src='noconfigure.png'>"
+                    testfield += "<img title='Requires -b option' src='noconfigure.png' alt='No-configure icon'>"
                 if self.get(dev, "rating") == "excellent":
-                    testfield += "<img src='star.png'/><img src='star.png'/><img src='star.png'/><img src='star.png'/>"
+                    testfield += "<img src='star.png' alt='Star icon'><img src='star.png' alt='Star icon'><img src='star.png' alt='Star icon'><img src='star.png' alt='Star icon'>"
                 elif self.get(dev, "rating") == "good":
-                    testfield += "<img src='star.png'/><img src='star.png'/'><img src='star.png'/>"
+                    testfield += "<img src='star.png' alt='Star icon'><img src='star.png' alt='Star icon'><img src='star.png' alt='Star icon'>"
                 elif self.get(dev, "rating") == "fair":
-                    testfield += "<img src='star.png'/><img src='star.png'/>"
+                    testfield += "<img src='star.png' alt='Star icon'><img src='star.png' alt='Star icon'>"
                 elif self.get(dev, "rating") == "poor":
-                    testfield += "<img src='star.png'/>"
+                    testfield += "<img src='star.png' alt='Star icon'>"
                 elif self.get(dev, "rating") == "broken":
-                    testfield += "<img title='Device is broken' src='bomb.png'/>"
+                    testfield += "<img title='Device is broken' src='bomb.png' alt='Bomb icon'>"
                 if self.has_option(dev, "usbchip") and self.get(dev, "usbchip") in hotpluggables:
-                    testfield += "<img src='hotplug.png'/>"
+                    testfield += "<img src='hotplug.png' alt='Hotplug icon'>"
                 ofp.write("<td>%s</td>\n" % testfield)
                 nmea = "&nbsp;"
                 if self.has_option(dev, "nmea"):
