@@ -414,7 +414,7 @@ width="600" height="600"/>
 <p class="caption">A filled circle means the satellite was used in
 the last fix. Green-yellow-red colors indicate signal strength in dB,
 green=most and red=least.  Diamonds indicate SBAS satellites.</p>
-{$gmap_code}</td>
+{$map_code}</td>
 </tr>
 EOF;
 
@@ -630,7 +630,7 @@ function Load() {
 EOT;
 }
 
-function gen_gmap_code() {
+function gen_map_code() {
 return <<<EOT
 <br/>
 <div id="map" style="width: 550px; height: 400px; border:1px; border-style: solid;">
