@@ -63,14 +63,13 @@ PERMISSIONS
 #include <stdlib.h>
 #include <stdbool.h>
 #include <stdarg.h>
-#include <locale.h>
 #include <ctype.h>
 
 #include "gpsd_config.h"	/* for strlcpy() prototype */
 #ifdef SOCKET_EXPORT_ENABLE
 #include "json.h"
 
-#include "gps.h"		/* only for timestamp_t prototype */
+#include "gps.h"		/* for safe_atof() & timestamp_t prototype */
 
 #ifdef CLIENTDEBUG_ENABLE
 static int debuglevel = 0;
@@ -445,7 +444,7 @@ static int json_internal_read_object(const char *cp,
 		    *((double *)lptr) = iso8601_to_unix(valbuf);
 		    break;
 		case t_real:
-		    *((double *)lptr) = atof(valbuf);
+		    *((double *)lptr) = safe_atof(valbuf);
 		    break;
 		case t_string:
 		    if (parent != NULL
@@ -604,14 +603,10 @@ int json_read_array(const char *cp, const struct json_array_t *arr,
 int json_read_object(const char *cp, const struct json_attr_t *attrs,
 		     /*@null@*/ const char **end)
 {
-    char *savedlocale = setlocale(LC_ALL, NULL);
     int st;
 
-    /* temporary locale setting is required wherever ',' is the decimal point */
-    (void)setlocale(LC_ALL, "C");
     json_debug_trace((1, "json_read_object() sees '%s'\n", cp));
     st = json_internal_read_object(cp, attrs, NULL, 0, end);
-    (void)setlocale(LC_ALL, savedlocale);
     return st;
 }
 
