@@ -15,6 +15,7 @@
 #include <stdarg.h>
 
 #include "gpsd.h"
+#include "libgps.h"
 #include "gps_json.h"
 
 #ifdef LIBGPS_DEBUG
@@ -62,7 +63,7 @@ int gps_open(/*@null@*/const char *host,
 {
     int status = -1;
 
-    /*@ -branchstate @*/
+    /*@ -branchstate -compdef @*/
     if (!gpsdata)
 	return -1;
 
@@ -76,6 +77,15 @@ int gps_open(/*@null@*/const char *host,
     }
 #endif /* SHM_EXPORT_ENABLE */
 
+#ifdef DBUS_EXPORT_ENABLE
+    if (host != NULL && strcmp(host, GPSD_DBUS_EXPORT) == 0) {
+	/*@i@*/status = gps_dbus_open(gpsdata);
+	if (status != 0)
+	    /* FIXME: it would be better not to throw away information here */
+	    status = DBUS_FAILURE;
+    }
+#endif /* DBUS_EXPORT_ENABLE */
+
 #ifdef SOCKET_EXPORT_ENABLE
     if (status == -1) {
         status = gps_sock_open(host, port, gpsdata);
@@ -84,10 +94,12 @@ int gps_open(/*@null@*/const char *host,
 
     gpsdata->set = 0;
     gpsdata->status = STATUS_NO_FIX;
-    gps_clear_fix(&gpsdata->fix);
+    gpsdata->satellites_used = 0;
+    gps_clear_fix(&(gpsdata->fix));
+    gps_clear_dop(&(gpsdata->dop));
 
     return status;
-    /*@ +branchstate @*/
+    /*@ +branchstate +compdef @*/
 }
 
 int gps_close(struct gps_data_t *gpsdata)
@@ -118,7 +130,7 @@ int gps_read(struct gps_data_t *gpsdata)
 {
     int status = -1;
 
-    libgps_debug_trace((DEBUG_CALLS, "gps_read()\n"));
+    libgps_debug_trace((DEBUG_CALLS, "gps_read() begins\n"));
 
     /*@ -usedef -compdef -uniondef @*/
 #ifdef SHM_EXPORT_ENABLE
@@ -134,6 +146,9 @@ int gps_read(struct gps_data_t *gpsdata)
 #endif /* SOCKET_EXPORT_ENABLE */
     /*@ +usedef +compdef +uniondef @*/
 
+    libgps_debug_trace((DEBUG_CALLS, "gps_read() -> %d (%s)\n", 
+			status, gps_maskdump(gpsdata->set)));
+
     return status;
 }
 
@@ -170,9 +185,10 @@ int gps_stream(struct gps_data_t *gpsdata CONDITIONALLY_UNUSED,
     return status;
 }
 
-const char /*@observer@*/ *gps_data(const struct gps_data_t *gpsdata CONDITIONALLY_UNUSED)
+const char /*@null observer@*/ *gps_data(const struct gps_data_t *gpsdata CONDITIONALLY_UNUSED)
 /* return the contents of the client data buffer */
 {
+    /*@-dependenttrans -observertrans@*/
     const char *bufp = NULL;
 
 #ifdef SOCKET_EXPORT_ENABLE
@@ -180,6 +196,7 @@ const char /*@observer@*/ *gps_data(const struct gps_data_t *gpsdata CONDITIONAL
 #endif /* SOCKET_EXPORT_ENABLE */
 
     return bufp;
+    /*@+dependenttrans +observertrans@*/
 }
 
 bool gps_waiting(const struct gps_data_t *gpsdata CONDITIONALLY_UNUSED, int timeout CONDITIONALLY_UNUSED)
@@ -188,13 +205,47 @@ bool gps_waiting(const struct gps_data_t *gpsdata CONDITIONALLY_UNUSED, int time
     /* this is bogus, but I can't think of a better solution yet */
     bool waiting = true;
 
+#ifdef SHM_EXPORT_ENABLE
+    if ((intptr_t)(gpsdata->gps_fd) == SHM_PSEUDO_FD)
+	waiting = gps_shm_waiting(gpsdata, timeout);
+#endif /* SHM_EXPORT_ENABLE */
+
 #ifdef SOCKET_EXPORT_ENABLE
-    waiting = gps_sock_waiting(gpsdata, timeout);
+    if ((intptr_t)(gpsdata->gps_fd) >= 0)
+	waiting = gps_sock_waiting(gpsdata, timeout);
 #endif /* SOCKET_EXPORT_ENABLE */
 
     return waiting;
 }
 
+int gps_mainloop(struct gps_data_t *gpsdata, int timeout, 
+		 void (*hook)(struct gps_data_t *gpsdata))
+{
+    int status = -1;
+
+    libgps_debug_trace((DEBUG_CALLS, "gps_mainloop() begins\n"));
+
+    /*@ -usedef -compdef -uniondef @*/
+#ifdef SHM_EXPORT_ENABLE
+    if ((intptr_t)(gpsdata->gps_fd) == SHM_PSEUDO_FD)
+	status = gps_shm_mainloop(gpsdata, timeout, hook);
+#endif /* SHM_EXPORT_ENABLE */
+#ifdef DBUS_EXPORT_ENABLE
+    if ((intptr_t)(gpsdata->gps_fd) == DBUS_PSEUDO_FD)
+	status = gps_dbus_mainloop(gpsdata, timeout, hook);
+#endif /* DBUS_EXPORT_ENABLE */
+#ifdef SOCKET_EXPORT_ENABLE
+    if ((intptr_t)(gpsdata->gps_fd) >= 0)
+	status = gps_sock_mainloop(gpsdata, timeout, hook);
+#endif /* SOCKET_EXPORT_ENABLE */
+    /*@ +usedef +compdef +uniondef @*/
+
+    libgps_debug_trace((DEBUG_CALLS, "gps_mainloop() -> %d (%s)\n", 
+			status, gps_maskdump(gpsdata->set)));
+
+    return status;
+}
+
 extern const char /*@observer@*/ *gps_errstr(const int err)
 {
     /* 
@@ -208,6 +259,10 @@ extern const char /*@observer@*/ *gps_errstr(const int err)
     else if (err == SHM_NOATTACH)
 	return "attach failed for unknown reason";
 #endif /* SHM_EXPORT_ENABLE */
+#ifdef DBUS_EXPORT_ENABLE
+    if (err == DBUS_FAILURE)
+	return "DBUS initialization failure";
+#endif /* DBUS_EXPORT_ENABLE */
     return netlib_errstr(err);
 #else
     static char buf[32];
