@@ -17,14 +17,25 @@ PERMISSIONS
 #include <stddef.h>
 #include <string.h>
 #include <errno.h>
+#include <stdlib.h>
 #include <sys/time.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
 
 #include "gpsd.h"
+#include "libgps.h"
 
 #ifdef SHM_EXPORT_ENABLE
 
+/*@-matchfields@*/
+struct privdata_t
+{
+    void *shmseg;
+    int tick;
+};
+/*@+matchfields@*/
+
+
 int gps_shm_open(/*@out@*/struct gps_data_t *gpsdata)
 /* open a shared-memory connection to the daemon */
 {
@@ -38,19 +49,44 @@ int gps_shm_open(/*@out@*/struct gps_data_t *gpsdata)
 	/* daemon isn't running or failed to create shared segment */
 	return -1;
     } 
-    gpsdata->privdata = shmat(shmid, 0, 0);
+    gpsdata->privdata = (void *)malloc(sizeof(struct privdata_t));
+    if (gpsdata->privdata == NULL)
+	return -1;
+
+    PRIVATE(gpsdata)->shmseg = shmat(shmid, 0, 0);
     if ((int)(long)gpsdata->privdata == -1) {
 	/* attach failed for sume unknown reason */
 	return -2;
     }
 #ifndef USE_QT
-    gpsdata->gps_fd = -1;
+    gpsdata->gps_fd = SHM_PSEUDO_FD;
 #else
-    gpsdata->gps_fd = (void *)(intptr_t)-1;
+    gpsdata->gps_fd = (void *)(intptr_t)SHM_PSEUDO_FD;
 #endif /* USE_QT */
     return 0;
 }
 
+bool gps_shm_waiting(const struct gps_data_t *gpsdata, int timeout)
+/* check to see if new dayta has been written */
+{
+    volatile struct shmexport_t *shared = (struct shmexport_t *)PRIVATE(gpsdata)->shmseg;
+    bool newdata;
+    timestamp_t basetime = timestamp();
+
+    /* busy-waiting sucks, but there's not really an alternative */
+    for (;;) {
+	newdata = false;
+	barrier();
+	if (shared->bookend1 == shared->bookend2 && shared->bookend1 > PRIVATE(gpsdata)->tick + timeout)
+	    newdata = true;
+	barrier();
+	if (newdata || (timestamp() - basetime >= (double)timeout))
+	    break;
+    }
+
+    return true;
+}
+
 int gps_shm_read(struct gps_data_t *gpsdata)
 /* read an update from the shared-memory segment */
 {
@@ -61,7 +97,7 @@ int gps_shm_read(struct gps_data_t *gpsdata)
     {
 	int before, after;
 	void *private_save = gpsdata->privdata;
-	volatile struct shmexport_t *shared = (struct shmexport_t *)gpsdata->privdata;
+	volatile struct shmexport_t *shared = (struct shmexport_t *)PRIVATE(gpsdata)->shmseg;
 	struct gps_data_t noclobber;
 
 	/*
@@ -90,6 +126,7 @@ int gps_shm_read(struct gps_data_t *gpsdata)
 			 (void *)&noclobber, 
 			 sizeof(struct gps_data_t));
 	    /*@i1@*/gpsdata->privdata = private_save;
+	    PRIVATE(gpsdata)->tick = after;
 	    if ((gpsdata->set & REPORT_IS)!=0) {
 		if (gpsdata->fix.mode >= 2)
 		    gpsdata->status = STATUS_FIX;
@@ -105,8 +142,27 @@ int gps_shm_read(struct gps_data_t *gpsdata)
 
 void gps_shm_close(struct gps_data_t *gpsdata)
 {
-    if (gpsdata->privdata != NULL)
-	(void)shmdt((const void *)gpsdata->privdata);
+    if (PRIVATE(gpsdata)->shmseg != NULL)
+	(void)shmdt((const void *)PRIVATE(gpsdata)->shmseg);
+}
+
+int gps_shm_mainloop(struct gps_data_t *gpsdata, int timeout UNUSED, 
+			 void (*hook)(struct gps_data_t *gpsdata))
+/* run a shm main loop with a specified handler */
+{
+    for (;;) {
+	if (!gps_shm_waiting(gpsdata, timeout)) {
+	    return -1;
+	} else {
+	    int status = gps_shm_read(gpsdata);
+
+	    if (status == -1)
+		return -1;
+	    if (status > 0)
+		(*hook)(gpsdata);
+	}
+    }
+    //return 0;
 }
 
 #endif /* SHM_EXPORT_ENABLE */
