@@ -31,6 +31,7 @@
 
 #include "gps.h"
 #include "gpsd.h"
+#include "libgps.h"
 #ifdef SOCKET_EXPORT_ENABLE
 #include "gps_json.h"
 
@@ -38,6 +39,7 @@
 extern char *strtok_r(char *, const char *, char **);
 #endif /* S_SPLINT_S */
 
+/*@-matchfields@*/
 struct privdata_t
 {
     bool newstyle;
@@ -48,7 +50,7 @@ struct privdata_t
     int waitcount;
 #endif /* LIBGPS_DEBUG */
 };
-#define PRIVATE(gpsdata) ((struct privdata_t *)gpsdata->privdata)
+/*@+matchfields@*/
 
 /*@-branchstate@*/
 int gps_sock_open(/*@null@*/const char *host, /*@null@*/const char *port,
@@ -565,6 +567,21 @@ int gps_sock_stream(struct gps_data_t *gpsdata, unsigned int flags,
     }
 }
 
+int gps_sock_mainloop(struct gps_data_t *gpsdata, int timeout, 
+			 void (*hook)(struct gps_data_t *gpsdata))
+/* run a socket main loop with a specified handler */
+{
+    for (;;) {
+	if (!gps_waiting(gpsdata, timeout)) {
+	    return -1;
+	} else {
+	    (void)gps_read(gpsdata);
+	    (*hook)(gpsdata);
+	}
+    }
+    //return 0;
+}
+
 #endif /* SOCKET_EXPORT_ENABLE */
 
 /* end */
