@@ -75,6 +75,7 @@ static const char *pos_hold_mode[] = {
 
 static bool oncore_initialize(void)
 {
+    /*@-globstate@*/
     unsigned int i;
 
     /*@ -onlytrans @*/
@@ -89,7 +90,7 @@ static bool oncore_initialize(void)
     /*@ +onlytrans @*/
 
     if (Ea1win == NULL || Eawin == NULL || Bbwin == NULL || Enwin == NULL
-	|| Bowin == NULL || Aswin == NULL || Atwin == NULL)
+	|| Bowin == NULL || Aswin == NULL || Atwin == NULL || Aywin == NULL)
 	return false;
 
     (void)syncok(Ea1win, true);
@@ -169,6 +170,7 @@ static bool oncore_initialize(void)
     memset(EaSVlines, 0, sizeof(EaSVlines));
 
     return true;
+    /*@+globstate@*/
 }
 
 static void oncore_update(void)
