@@ -6,6 +6,7 @@
  */
 #include "gpsd.h"
 #include "gpsmon.h"
+#include "assert.h"
 
 #ifdef TNT_ENABLE
 extern const struct gps_type_t trueNorth;
@@ -14,8 +15,10 @@ static WINDOW *thtmwin;
 
 static bool tnt_initialize(void)
 {
+    /*@-globstate@*/
     /*@ -onlytrans @*/
     thtmwin = derwin(devicewin, 6, 80, 0, 0);
+    assert(thtmwin != NULL);
     (void)wborder(thtmwin, 0, 0, 0, 0, 0, 0, 0, 0),
 	(void)syncok(thtmwin, true);
     (void)wattrset(thtmwin, A_BOLD);
@@ -32,6 +35,7 @@ static bool tnt_initialize(void)
     (void)wattrset(thtmwin, A_NORMAL);
     /*@ +onlytrans @*/
     return true;
+    /*@+globstate@*/
 }
 
 static void tnt_update(void)
