@@ -20,7 +20,7 @@
 #endif /* S_SPLINT_S */
 
 #include "gpsd.h"
-#include "bsd-base64.h"
+#include "bsd_base64.h"
 
 #define NTRIP_SOURCETABLE	"SOURCETABLE 200 OK\r\n"
 #define NTRIP_ENDSOURCETABLE	"ENDSOURCETABLE"
@@ -74,7 +74,7 @@ static void ntrip_str_parse(char *str, size_t len,
 
     /* <mountpoint> */
     if ((s = ntrip_field_iterate(str, NULL, eol)))
-	strncpy(hold->mountpoint, s, sizeof(hold->mountpoint) - 1);
+	(void)strlcpy(hold->mountpoint, s, sizeof(hold->mountpoint));
     /* <identifier> */
     s = ntrip_field_iterate(NULL, s, eol);
     /* <format> */
@@ -313,8 +313,9 @@ static int ntrip_stream_req_probe(const struct ntrip_stream_t *stream)
     (void)snprintf(buf, sizeof(buf),
 	    "GET / HTTP/1.1\r\n"
 	    "User-Agent: NTRIP gpsd/%s\r\n"
+	    "Host: %s\r\n"
 	    "Connection: close\r\n"
-	    "\r\n", VERSION);
+	    "\r\n", VERSION, stream->url);
     r = write(dsock, buf, strlen(buf));
     if (r != (ssize_t)strlen(buf)) {
 	gpsd_report(LOG_ERROR, "ntrip stream write error %d on fd %d during probe request %zd\n",
@@ -367,10 +368,11 @@ static int ntrip_stream_get_req(const struct ntrip_stream_t *stream)
     (void)snprintf(buf, sizeof(buf),
 	    "GET /%s HTTP/1.1\r\n"
 	    "User-Agent: NTRIP gpsd/%s\r\n"
+	    "Host: %s\r\n"
 	    "Accept: rtk/rtcm, dgps/rtcm\r\n"
 	    "%s"
 	    "Connection: close\r\n"
-	    "\r\n", stream->mountpoint, VERSION, stream->authStr);
+	    "\r\n", stream->mountpoint, VERSION, stream->url, stream->authStr);
     if (write(dsock, buf, strlen(buf)) != (ssize_t) strlen(buf)) {
 	gpsd_report(LOG_ERROR, "ntrip stream write error %d on fd %d during get request\n", errno,
 		dsock);
@@ -436,7 +438,7 @@ int ntrip_open(struct gps_device_t *device, char *caster)
     char *port = NULL;
     char *stream = NULL;
     char *url = NULL;
-    int ret;
+    int ret = -1;
     char t[strlen(caster + 1)];
     char *tmp = t;
 
@@ -485,10 +487,19 @@ int ntrip_open(struct gps_device_t *device, char *caster)
 		    port = DEFAULT_RTCM_PORT;
 	    }
 
-	    strncpy(device->ntrip.stream.mountpoint, stream, 101); /* magic numbers from struct definitions */
-	    strncpy(device->ntrip.stream.credentials, auth, 128); /* magic numbers from struct definitions */
-	    strncpy(device->ntrip.stream.url, url, 256);
-	    strncpy(device->ntrip.stream.port, port, 32);
+	    (void)strlcpy(device->ntrip.stream.mountpoint, 
+		    stream, 
+		    sizeof(device->ntrip.stream.mountpoint));
+	    if (auth != NULL)
+		(void)strlcpy(device->ntrip.stream.credentials, 
+			      auth, 
+			      sizeof(device->ntrip.stream.credentials));
+	    (void)strlcpy(device->ntrip.stream.url, 
+		    url, 
+		    sizeof(device->ntrip.stream.url));
+	    (void)strlcpy(device->ntrip.stream.port, 
+		    port, 
+		    sizeof(device->ntrip.stream.port));
 
 	    ret = ntrip_stream_req_probe(&device->ntrip.stream);
 	    if (ret == -1) {
