@@ -11,6 +11,7 @@
 #include <sys/stat.h>
 #include <sys/socket.h>
 #endif /* AF_UNSPEC */
+#include <sys/un.h>
 #ifndef INADDR_ANY
 #include <netinet/in.h>
 #endif /* INADDR_ANY */
@@ -146,6 +147,33 @@ char /*@observer@*/ *netlib_errstr(const int err)
     }
 }
 
+socket_t netlib_localsocket(const char *sockfile, int socktype)
+/* acquire a connection to an existing Unix-domain socket */
+{
+    int sock;
+
+    if ((sock = socket(AF_UNIX, socktype, 0)) < 0) {
+	return -1;
+    } else {
+	struct sockaddr_un saddr;
+
+	memset(&saddr, 0, sizeof(struct sockaddr_un));
+	saddr.sun_family = AF_UNIX;
+	(void)strlcpy(saddr.sun_path, 
+		      sockfile, 
+		      sizeof(saddr.sun_path));
+
+	/*@-unrecog@*/
+	if (connect(sock, (struct sockaddr *)&saddr, SUN_LEN(&saddr)) < 0) {
+	    (void)close(sock);
+	    return -1;
+	}
+	/*@+unrecog@*/
+
+	return sock;
+    }
+}
+
 char *netlib_sock2ip(int fd)
 /* retrieve the IP address corresponding to a socket */ 
 {
