@@ -51,9 +51,9 @@ PERMISSIONS
  *
  * 2) NMEA lines.  These begin with $, and with \r\n, and have a checksum.
  *
- * 3) Binary packets.  These begin with some fixed leader character(s),
- *    have a length embedded in them, and end with a checksum (and possibly)
- *    some fixed trailing bytes.
+ * 3) Checksummed binary packets.  These begin with some fixed leader
+ *    character(s), have a length embedded in them, and end with a
+ *    checksum (and possibly some fixed trailing bytes).
  *
  * 4) ISGPS packets. The input may be a bitstream containing IS-GPS-200
  *    packets.  Each includes a fixed leader byte, a length, and check bits.
@@ -61,6 +61,10 @@ PERMISSIONS
  *    bounaries; the recognizer has to run a separate state machine against
  *    each byte just to achieve synchronization lock with the bitstream.
  *
+ * 5) Un-checksummed binary packets.  Like case 3, but without
+ *    a checksum it's much easier to get a false match from garbage.
+ *    The packet recognizer gives checksummed types higher priority.
+ *
  * Adding support for a new GPS protocol typically reqires adding state
  * transitions to support whatever binary packet structure it has.  The
  * goal is for the lexer to be able to cope with arbitrarily mixed packet
@@ -90,7 +94,9 @@ PERMISSIONS
  *      GL -- GLONASS, according to IEIC 61162-1
  *      GN -- Mixed GPS and GLONASS data, according to IEIC 61162-1
  *      II -- Integrated Instrumentation (Raytheon's SeaTalk system).
- *	IN -- Integrated Navigation (Garmin uses this).
+ *      IN -- Integrated Navigation (Garmin uses this).
+ *      EC -- Electronic Chart Display & Information System (ECDIS)
+ *      P  -- Vendor-specific sentence
  *
  */
 
@@ -319,6 +325,8 @@ static void nextstate(struct gps_packet_t *lexer, unsigned char c)
 	    lexer->state = SEATALK_LEAD_1;
 	else if (c == 'A')	/* SiRF Ack */
 	    lexer->state = SIRF_ACK_LEAD_1;
+	else if (c == 'E')	/* ECDIS */
+	    lexer->state = ECDIS_LEAD_1;
 #ifdef OCEANSERVER_ENABLE
 	else if (c == 'C')
 	    lexer->state = NMEA_LEADER_END;
@@ -489,6 +497,12 @@ static void nextstate(struct gps_packet_t *lexer, unsigned char c)
 	else
 	    lexer->state = GROUND_STATE;
 	break;
+    case ECDIS_LEAD_1:
+	if (c == 'C')		/* ECDIS leader accepted */
+	    lexer->state = NMEA_LEADER_END;
+	else
+	    lexer->state = GROUND_STATE;
+	break;
 #ifdef TRIPMATE_ENABLE
     case ASTRAL_1:
 	if (c == 'S') {
@@ -1342,6 +1356,9 @@ void packet_init( /*@out@*/ struct gps_packet_t *lexer)
 #ifdef PASSTHROUGH_ENABLE
     lexer->json_depth = 0;
 #endif /* PASSTHROUGH_ENABLE */
+#ifdef TIMING_ENABLE
+    lexer->start_time = 0.0;
+#endif /* TIMING_ENABLE */
     packet_reset(lexer);
 }
 
