@@ -162,7 +162,6 @@ gps_mask_t gpsd_interpret_subframe(struct gps_device_t *session,
     uint8_t preamble;
     int i = 0;   /* handy loop counter */
     struct subframe_t *subp = &session->gpsdata.subframe;
-    session->gpsdata.set |= SUBFRAME_SET;
     gpsd_report(LOG_IO,
 		"50B: gpsd_interpret_subframe: (%d) "
 		"%06x %06x %06x %06x %06x %06x %06x %06x %06x %06x\n",
@@ -656,7 +655,7 @@ gps_mask_t gpsd_interpret_subframe(struct gps_device_t *session,
 
 		subp->sub4_17.str[i++] = (words[9] >> 16) & 0xff;
 		subp->sub4_17.str[i++] = (words[9] >> 8) & 0xff;
-		subp->sub4_17.str[i++] = '\0';
+		subp->sub4_17.str[i] = '\0';
 		/*@ +type @*/
 		gpsd_report(LOG_PROG, "50B: SF:4-17 system message: %.24s\n",
 			subp->sub4_17.str);
@@ -822,7 +821,7 @@ gps_mask_t gpsd_interpret_subframe(struct gps_device_t *session,
 	/* unknown/illegal subframe */
 	return 0;
     }
-    return SUBFRAME_IS;
+    return SUBFRAME_SET;
 }
 
 /*@ +usedef @*/
