@@ -188,6 +188,7 @@ timestamp_t gpsd_gpstime_resolve(/*@in@*/struct gps_device_t *session,
 {
     timestamp_t t;
 
+#ifdef __UNUSED__
     /*
      * This code detects and compensates for week counter rollovers that
      * happen while gpsd is running. It will not save you if there was a 
@@ -199,6 +200,7 @@ timestamp_t gpsd_gpstime_resolve(/*@in@*/struct gps_device_t *session,
 	gpsd_report(LOG_INF, "GPS week 10-bit rollover detected.\n");
 	++session->context->rollovers;
     }
+#endif /* __UNUSED__ */
 
     /*
      * This guard copes with both conventional GPS weeks and the "extended"
